@@ -26,7 +26,7 @@ class RsyncMain(BaseMain):
         context = self.context
         hosts = self.check_hosts()
         # prompt when production environment
-        rsync_command = 'rsync %s %s %s' % (context.options.rsync_options, context.source, context.destination)
+        rsync_command = 'rsync %s %s %s' % (context.options['rsync_options'], context.source, context.destination)
         self.confirm_execution_on_production(
             'Rsync command "%s" will be executed %d hosts. Are you sure? [yes/NO]: '
             % (rsync_command, len(hosts))
